@@ -106,9 +106,16 @@ static std::vector<std::string>TS480HX_FSKbw;
 static const char *vTS480HX_FSKbw[] =
 { "FW0250;", "FW0500;", "FW1000;", "FW1500;" };
 
-static int agcval = 1;
 static bool fm_mode = false;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>TS480HX_att_labels;
+static const char *vTS480HX_att_labels[] = { "ATT", "Att ON" };
+
+static std::vector<std::string>TS480HX_pre_labels;
+static const char *vTS480HX_pre_labels[] = { "PRE", "Pre ON" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 }, // 0
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 }, // 1
@@ -144,6 +151,12 @@ void RIG_TS480HX::initialize()
 	bandwidths_ = TS480HX_empty;
 	bw_vals_ = TS480HX_bw_vals;
 
+	VECTOR (TS480HX_att_labels, vTS480HX_att_labels);
+	VECTOR (TS480HX_pre_labels, vTS480HX_pre_labels);
+
+	att_labels_ = TS480HX_att_labels;
+	pre_labels_ = TS480HX_pre_labels;
+
 	rig_widgets[0].W = btnVol;
 	rig_widgets[1].W = sldrVOLUME;
 	rig_widgets[2].W = sldrRFGAIN;
@@ -237,10 +250,10 @@ RIG_TS480HX::RIG_TS480HX() {
 	precision = 1;
 	ndigits = 8;
 
-	_noise_reduction_level = 0;
+	nr_state = 0;
 	_nrval1 = 2;
 	_nrval2 = 4;
-	preamp_level = atten_level = 0;
+	preamp_state = atten_state = 0;
 }
 
 static int ret = 0;
@@ -315,9 +328,7 @@ int RIG_TS480HX::get_smeter()
 	return mtr;
 }
 
-struct pwrpair {int mtr; float pwr;};
-
-static pwrpair pwrtbl[] = { 
+static meterpair pwrtbl[] = { 
 	{0, 0.0}, 
 	{2, 5.0},
 	{4, 10.0}, 
@@ -340,13 +351,13 @@ int RIG_TS480HX::get_power_out()
 		mtr = atoi(&replystr[p + 3]);
 
 		size_t i = 0;
-		for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+		for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 			if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 				break;
 		if (mtr < 0) mtr = 0;
 		if (mtr > 20) mtr = 20;
-		mtr = (int)ceil(pwrtbl[i].pwr + 
-			(pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+		mtr = (int)ceil(pwrtbl[i].val + 
+			(pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 		if (mtr > 200) mtr = 200;
 	}
 	return mtr;
@@ -782,7 +793,7 @@ void RIG_TS480HX::set_attenuator(int val)
 	set_trace(1, "set attenuator");
 	sendCommand(cmd);
 	sett("");
-	atten_level = val;
+	atten_state = val;
 }
 
 int RIG_TS480HX::get_attenuator()
@@ -791,12 +802,12 @@ int RIG_TS480HX::get_attenuator()
 	get_trace(1, "get_attenuator");
 	ret = wait_char(';', 7, 100, "get attenuator", ASC);
 	gett("");
-	if (ret < 7) return atten_level;
+	if (ret < 7) return atten_state;
 
 	size_t p = replystr.rfind("RA");
 	if (p != std::string::npos)
-		atten_level = (replystr[p+3] == '1');
-	return atten_level;
+		atten_state = (replystr[p+3] == '1');
+	return atten_state;
 }
 
 void RIG_TS480HX::set_preamp(int val)
@@ -807,7 +818,7 @@ void RIG_TS480HX::set_preamp(int val)
 	set_trace(1, "set preamp");
 	sendCommand(cmd);
 	sett("");
-	preamp_level = val;
+	preamp_state = val;
 }
 
 int RIG_TS480HX::get_preamp()
@@ -816,24 +827,12 @@ int RIG_TS480HX::get_preamp()
 	get_trace(1, "get_preamp");
 	ret = wait_char(';', 5, 100, "get preamp", ASC);
 	gett("");
-	if (ret < 5) return preamp_level;
+	if (ret < 5) return preamp_state;
 
 	size_t p = replystr.rfind("PA");
 	if (p != std::string::npos)
-		preamp_level = (replystr[p+2] == '1');
-	return preamp_level;
-}
-
-const char *RIG_TS480HX::PRE_label()
-{
-	if (preamp_level == 1) return "Pre 1";
-	return "PRE";
-}
-
-const char *RIG_TS480HX::ATT_label()
-{
-	if (atten_level == 1) return "ON";
-	return "ATT";
+		preamp_state = (replystr[p+2] == '1');
+	return preamp_state;
 }
 
 void RIG_TS480HX::set_if_shift(int val)
@@ -877,16 +876,16 @@ void RIG_TS480HX::set_noise_reduction(int val)
 	if (val == -1) {
 		return;
 	}
-	_noise_reduction_level = val;
-	if (_noise_reduction_level == 0) {
-		nr_label("NR", false);
-	} else if (_noise_reduction_level == 1) {
-		nr_label("NR1", true);
-	} else if (_noise_reduction_level == 2) {
-		nr_label("NR2", true);
+	nr_state = val;
+	if (nr_state == 0) {
+		noise_reduction_label("NR", false);
+	} else if (nr_state == 1) {
+		noise_reduction_label("NR1", true);
+	} else if (nr_state == 2) {
+		noise_reduction_label("NR2", true);
 	}
 	cmd.assign("NR");
-	cmd += '0' + _noise_reduction_level;
+	cmd += '0' + nr_state;
 	cmd += ';';
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET noise reduction", cmd, "");
@@ -901,25 +900,25 @@ int  RIG_TS480HX::get_noise_reduction()
 	gett("");
 	if (ret == 4) {
 		size_t p = replystr.rfind(rsp);
-		if (p == std::string::npos) return _noise_reduction_level;
-		_noise_reduction_level = replystr[p+2] - '0';
+		if (p == std::string::npos) return nr_state;
+		nr_state = replystr[p+2] - '0';
 	}
 
-	if (_noise_reduction_level == 1) {
-		nr_label("NR1", true);
-	} else if (_noise_reduction_level == 2) {
-		nr_label("NR2", true);
+	if (nr_state == 1) {
+		noise_reduction_label("NR1", true);
+	} else if (nr_state == 2) {
+		noise_reduction_label("NR2", true);
 	} else {
-		nr_label("NR", false);
+		noise_reduction_label("NR", false);
 	}
 
-	return _noise_reduction_level;
+	return nr_state;
 }
 
 void RIG_TS480HX::set_noise_reduction_val(int val)
 {
-	if (_noise_reduction_level == 0) return;
-	if (_noise_reduction_level == 1) _nrval1 = val;
+	if (nr_state == 0) return;
+	if (nr_state == 1) _nrval1 = val;
 	else _nrval2 = val;
 
 	cmd.assign("RL").append(to_decimal(val, 2)).append(";");
@@ -930,7 +929,7 @@ void RIG_TS480HX::set_noise_reduction_val(int val)
 int  RIG_TS480HX::get_noise_reduction_val()
 {
 	int nrval = 0;
-	if (_noise_reduction_level == 0) return 0;
+	if (nr_state == 0) return 0;
 	int val = progStatus.noise_reduction_val;
 	cmd = rsp = "RL";
 	cmd.append(";");
@@ -940,13 +939,13 @@ int  RIG_TS480HX::get_noise_reduction_val()
 	if (ret == 5) {
 		size_t p = replystr.rfind(rsp);
 		if (p == std::string::npos) {
-			nrval = (_noise_reduction_level == 1 ? _nrval1 : _nrval2);
+			nrval = (nr_state == 1 ? _nrval1 : _nrval2);
 			return nrval;
 		}
 		val = atoi(&replystr[p+2]);
 	}
 
-	if (_noise_reduction_level == 1) _nrval1 = val;
+	if (nr_state == 1) _nrval1 = val;
 	else _nrval2 = val;
 
 	return val;
