@@ -38,13 +38,11 @@ bool SERIALDEBUG = false;
 
 bool check_hex(const void *s, size_t len)
 {
-	unsigned char *str = (unsigned char *)s;
-	for (size_t n = 0; n < len; n++) {
-		if (str[n] == '\r' || str[n] == '\n') continue;
-		if (str[n] < 0x20) return true;
-		if (str[n] > 0x7F) return true;
-	}
-	return false;
+    unsigned char *str = (unsigned char *)s;
+    for (size_t n = 0; n < len; n++) {
+        if (!isprint(str[n])) return true;
+    }
+    return false;
 }
 
 #ifndef __WIN32__
@@ -255,9 +253,11 @@ bool Cserial::getPTT() {
 
 void Cserial::SetPTT(bool ON)
 {
+	serptt = ON;
 	if (fd < 0) {
 		if (progStatus.serialtrace || SERIALDEBUG) {
-			snprintf(traceinfo, sizeof(traceinfo), "SetPTT(...) fd < 0");
+			snprintf(traceinfo, sizeof(traceinfo), "SetPTT(...) fd < 0, PTT = %s",
+				(ON ? "ON" : "OFF") );
 			ser_trace(1, traceinfo);
 		}
 		LOG_ERROR("ptt fd < 0");
@@ -290,7 +290,6 @@ void Cserial::SetPTT(bool ON)
 		}
 		ioctl(fd, TIOCMSET, &state);
 	}
-	serptt = ON;
 }
 
 void Cserial::setRTS(bool b)
@@ -408,19 +407,18 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 	FD_ZERO (&rfds);
 	FD_SET (fd, &rfds);
 
-	bool     timedout = false,
-			 echo = false;
+	bool     timedout = false;
+
 	int      bytes = 0;
-	size_t   retval = 0,
-			 maxchars = nchars + bytes_written,
-			 tnow = 0,
-			 start = 0;
+	ullint   retval = 0,
+			 start = 0,
+			 tout = progStatus.serial_timeout * 1000;
 
 	buf.clear();
 
-	start = tnow = zusec();
+	start = zusec();
 
-	while (1) {
+	while ( (zusec() - start) < tout ) {
 		memset(uctemp, 0, sizeof(uctemp));
 		ioctl( fd, FIONREAD, &bytes);
 		if (bytes) {
@@ -430,38 +428,61 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 				}
 			}
 		}
-		if (!find1.empty() && buf.find(find1) == (buf.length() - find1.length())) break;
-		if (!find2.empty() && buf.find(find2) == (buf.length() - find2.length())) break;
 
-		timedout = ( (zusec() - tnow) > (size_t)(progStatus.serial_timeout * 1000));
+// This block only for CI-V strings
+		if (buf.length() >= 4) {
+			// make sure we have the 0xfd for Icom
+			if ( ((buf[0] & 0xFF) == 0xFE) && 
+				 ((buf[1] & 0xFF) == 0xFE)) {
+				// if our last char isn't 0xfd get some more
+				if (buf[buf.length() - 1] != '\xfd') {
+					if (progStatus.serialtrace) {
+						hex = check_hex(buf.c_str(), buf.length());
+						double readtime = (zusec() - start) / 1000.0;
+						snprintf(traceinfo, sizeof(traceinfo), 
+							"Icom get more data [%0.2f msec] (%u): %s",
+							readtime, (unsigned int)buf.length(), 
+							(hex ? str2hex(buf.c_str(),buf.length()) : buf.c_str()));
+						ser_trace(2, "0:", traceinfo);
+					}
+					continue;
+				}
 
-		// test for icom echo
-		if ((buf.length() >= (size_t)nchars) && ((buf[3] & 0xFF) == 0xE0))
-			echo = true;
-		if (buf.length() >= (echo ? maxchars : (size_t)nchars)) break;
+// test for icom echo
+				if ((buf[3] & 0xFF) == 0xE0) { 
+					size_t pos = buf.find('\xfd');
+					if (pos != std::string::npos) {
+						if (progStatus.serialtrace) {
+							hex = check_hex(buf.c_str(), buf.length());
+							double readtime = (zusec() - start) / 1000.0;
+							snprintf(traceinfo, sizeof(traceinfo), 
+								"ReadEcho [%0.2f msec] (%u): %s",
+								readtime, (unsigned int)buf.length(), 
+								(hex ? str2hex(buf.c_str(),buf.length()) : buf.c_str()));
+							ser_trace(2, "1:", traceinfo);
+						}
+						buf = buf.substr(pos + 1);
+					}
+				}
+			}
+		}
+// end ICOM CI-V parsing
 
-		if (timedout) break;
+		if ( buf.length() >= (size_t)nchars) break;
+
+		if ( !find1.empty() && 
+			(buf.find(find1) != std::string::npos) &&
+			(buf.find(find1) == (buf.length() - find1.length()) ) ) break;
+
+		// This covers the Icom case of either 0xFA or 0xFD
+        if ( !find2.empty() &&
+			( buf.find(find2) != std::string::npos ) &&
+			(buf.find(find2) == (buf.length() - find2.length()) ) ) break;
 
 		MilliSleep(1);
 	}
 
-	if (echo)
-		buf = buf.substr(bytes_written);
-	if (buf.length() > (size_t)nchars) buf.erase(nchars);
-
-	size_t readtime = zusec() - start;
-
-	memset(traceinfo, 0, sizeof(traceinfo));
-	hex = check_hex(buf.c_str(), buf.length());
-
-	snprintf(traceinfo, sizeof(traceinfo), 
-		"ReadBuffer [%f msec]: %s",
-		readtime / 1000.0,
-		(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()));
-
-	LOG_DEBUG("%s", traceinfo);
-	if (progStatus.serialtrace)
-		ser_trace(1, traceinfo);
+	ullint readtime = zusec() - start;
 
 	if (timedout) {
 		memset(traceinfo, 0, sizeof(traceinfo));
@@ -472,6 +493,18 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 			buf.length());
 		LOG_ERROR("%s", traceinfo);
 
+		if (progStatus.serialtrace)
+			ser_trace(1, traceinfo);
+	} else {
+		memset(traceinfo, 0, sizeof(traceinfo));
+		hex = check_hex(buf.c_str(), buf.length());
+
+		snprintf(traceinfo, sizeof(traceinfo), 
+			"ReadBuffer [%f msec]: %s",
+			readtime / 1000.0,
+			(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()));
+
+		LOG_DEBUG("%s", traceinfo);
 		if (progStatus.serialtrace)
 			ser_trace(1, traceinfo);
 	}
@@ -505,14 +538,23 @@ int Cserial::WriteBuffer(const char *buff, int n)
 	}
 
 	FlushBuffer();
-	int ret = write (fd, buff, n);
 
-	bytes_written = n;
+	if (progStatus.serial_write_delay) {
+		size_t ret = 0;
+		for (int i = 0; i < n; i++) {
+			ret = write (fd, &buff[i], 1);
+			bytes_written += ret;
+			MilliSleep(progStatus.serial_write_delay);
+		}
+	} else {
+		size_t ret = write (fd, buff, n);
+		bytes_written = ret;
+	}
 
 	if (progStatus.serial_post_write_delay)
 		MilliSleep(progStatus.serial_post_write_delay);
 
-	return ret;
+	return bytes_written;
 }
 
 ///////////////////////////////////////////////////////
@@ -733,78 +775,109 @@ int  Cserial::ReadBuffer (std::string &buf, int nchars, std::string find1, std::
 		if (p != std::string::npos) s2.replace(p,1,"<lf>");
 	}
 
-//	bool  find_two = (!find1.empty() && !find2.empty());
-//	bool  find_one = (!find1.empty() && find2.empty());
-
-//	if (find_two)
-//		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer: %s  |  %s", s1.c_str(), s2.c_str());
-//	else if (find_one)
-//		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer XXX: %s", s1.c_str());
-//	else
-//		snprintf(traceinfo, sizeof(traceinfo), "ReadBuffer: %d chars", nchars);
-
-//	LOG_DEBUG("%s", traceinfo);
-//	if (progStatus.serialtrace)
-//		ser_trace(1, traceinfo);
-
 	memset(traceinfo, 0, sizeof(traceinfo));
 
 	long unsigned int thisread = 0;
 	size_t maxchars = nchars + nBytesWritten;
-	double start = zusec();
+	ullint start = 0;
+	ullint tout = progStatus.serial_timeout * 1000;
+
+	int nread = 0;
 
-	bool echo = false;
 	bool retval = false;
 
-	std::string sbuf;
-	sbuf.clear();
+	buf.clear();
 
-	while ( (zusec() - start) < (progStatus.serial_timeout * 1000.0) ) {
+	start = zusec();
+
+	while ( (zusec() - start) < tout ) {
 		memset(uctemp, 0, sizeof(uctemp));
 		if ( (retval = ReadFile (hComm, uctemp, maxchars, &thisread, NULL)) ) {
 			for (size_t n = 0; n < thisread && n < sizeof(uctemp); n++) {
-				sbuf += uctemp[n];
+				buf += uctemp[n];
+				++nread;
 			}
 		}
-		// test for icom echo
-		if ((sbuf.length() >= (size_t)nchars) && ((sbuf[3] & 0xFF) == 0xE0))
-			echo = true;
-		if (sbuf.length() >= (echo ? maxchars : (size_t)nchars)) break;
-		if (!find1.empty() && sbuf.find(find1) == (sbuf.length() - find1.length())) break;
-		if (!find2.empty() && sbuf.find(find2) == (sbuf.length() - find2.length())) break;
-		
+		// This block only for CI-V strings
+		if (buf.length() >= 4) {
+			// make sure we have the 0xfd for Icom
+			if ( ((buf[0] & 0xFF) == 0xFE) && 
+				 ((buf[1] & 0xFF) == 0xFE)) {
+				// if our last char isn't 0xfd get some more
+				if (buf[buf.length() - 1] != '\xfd') {
+					hex = check_hex(buf.c_str(), buf.length());
+					double readtime = (zusec() - start) / 1000.0;
+					snprintf(traceinfo, sizeof(traceinfo), 
+						"Icom get more data [%0.2f msec] (%u): %s",
+						readtime, (unsigned int)buf.length(), 
+						(hex ? str2hex(buf.c_str(),buf.length()) : buf.c_str()));
+					if (progStatus.serialtrace)
+						ser_trace(2, "0:", traceinfo);
+					continue;
+				}
+
+				// test for icom echo
+				if ((buf[3] & 0xFF) == 0xE0) { 
+					size_t pos = buf.find('\xfd');
+					if (pos != std::string::npos) {
+						hex = check_hex(buf.c_str(), buf.length());
+						double readtime = (zusec() - start) / 1000.0;
+						snprintf(traceinfo, sizeof(traceinfo), 
+							"ReadEcho [%0.2f msec] (%u): %s",
+							readtime, (unsigned int)buf.length(), 
+							(hex ? str2hex(buf.c_str(),buf.length()) : buf.c_str()));
+						if (progStatus.serialtrace)
+							ser_trace(2, "1:", traceinfo);
+						buf = buf.substr(pos + 1);
+					}
+					nread = buf.length();
+				}
+			}
+		}
+// end ICOM CI-V parsing
+
+		if ( buf.length() >= (size_t)nchars) break;
+
+		if ( !find1.empty() && 
+			(buf.find(find1) != std::string::npos) &&
+			(buf.find(find1) == (buf.length() - find1.length()) ) ) break;
+
+		// This covers the Icom case of either 0xFA or 0xFD
+        if ( !find2.empty() &&
+			( buf.find(find2) != std::string::npos ) &&
+			(buf.find(find2) == (buf.length() - find2.length()) ) ) break;
+
 		if (!thisread || !retval) MilliSleep(1);
 	}
 
+	hex = check_hex(buf.c_str(), buf.length());
 	double readtime = (zusec() - start) / 1000.0;
 	snprintf(traceinfo, sizeof(traceinfo), 
-		"ReadBuffer [%0.2f msec] (%u): %s",
-		readtime, (unsigned int)sbuf.length(), 
-		(hex ? str2hex(buf.c_str(), (unsigned  int)buf.length()) : sbuf.c_str()));
+		"ReadBuffer3 [%0.2f msec] (%u): %s",
+		readtime, (unsigned int)buf.length(), 
+		(hex ? str2hex(buf.c_str(),buf.length()) : buf.c_str()));
+
 	if (progStatus.serialtrace)
 		ser_trace(2, "1:", traceinfo);
 
-	if (echo)
-		sbuf = sbuf.substr(nBytesWritten);
-	if (sbuf.length() > (size_t)nchars) sbuf.erase(nchars);
 
-	buf = sbuf;
-	int nread = (int)buf.length();
+#if 0
+	snprintf(traceinfo, sizeof(traceinfo), 
+	"ReadBuffer [%0.2f msec] (%d): %s",
+		readtime, nread, 
+		(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()));
 
-//	snprintf(traceinfo, sizeof(traceinfo), 
-//		"ReadBuffer [%0.2f msec] (%d): %s",
-//		readtime, nread, 
-//		(hex ? str2hex(buf.c_str(), buf.length()) : buf.c_str()));
+	LOG_DEBUG("%s", traceinfo);
+	if (progStatus.serialtrace)
+		ser_trace(1, traceinfo);
+#endif
 
-//	LOG_DEBUG("%s", traceinfo);
-//	if (progStatus.serialtrace)
-//		ser_trace(1, traceinfo);
-
-	if (nread >= nchars) return nread;
+	if ( ( nread >= nchars ) || ( !hex && (strchr(buf.c_str(),';') != NULL ) ) )
+		return nread;
 
 	snprintf(traceinfo, sizeof(traceinfo), 
-		"ReadBuffer FAILED [%0.2f msec], read %d bytes",
-		readtime, nread);
+		"ReadBuffer4 FAILED [%0.2f msec], read %d bytes, expected %d bytes",
+		readtime, nread, nchars);
 	LOG_ERROR("%s", traceinfo);
 
 	if (progStatus.serialtrace)
@@ -860,9 +933,21 @@ int Cserial::WriteBuffer(const char *buff, int n)
 			ser_trace(2, "WriteBuffer: ", (hex ? str2hex(sw.c_str(), sw.length()) : sw.c_str()));
 		}
 	}
+
 	FlushBuffer();
-	WriteFile (hComm, buff, n,  &nBytesWritten, NULL);
-	
+
+	if (progStatus.serial_write_delay) {
+		int total = 0;
+		for (int i = 0; i < n; i++) {
+			WriteFile (hComm, &buff[i], 1,  &nBytesWritten, NULL);
+			total += nBytesWritten;
+			MilliSleep(progStatus.serial_write_delay);
+		}
+		nBytesWritten = total;
+	} else {
+		WriteFile (hComm, buff, n,  &nBytesWritten, NULL);
+	}
+
 	if (progStatus.serial_post_write_delay)
 		MilliSleep(progStatus.serial_post_write_delay);
 
